# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from .generate_template_previews_response_pdf_preview import GenerateTemplatePreviewsResponsePdfPreview
from .generate_template_previews_response_png_preview import GenerateTemplatePreviewsResponsePngPreview


class GenerateTemplatePreviewsResponse(UniversalBaseModel):
    png_preview: typing_extensions.Annotated[
        GenerateTemplatePreviewsResponsePngPreview, FieldMetadata(alias="pngPreview")
    ]
    pdf_preview: typing_extensions.Annotated[
        GenerateTemplatePreviewsResponsePdfPreview, FieldMetadata(alias="pdfPreview")
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
