# This file was auto-generated by Fern from our API Definition.

import typing

StartImmediateRenderRequestType = typing.Union[
    typing.Literal["docx", "xlsx", "pptx", "ejs", "html", "latex", "react"], typing.Any
]
