# This file was auto-generated by Fern from our API Definition.

import typing

StartRenderJobResponseFormatOptsFormat = typing.Union[
    typing.Literal["letter", "legal", "tabloid", "ledger", "a0", "a1", "a2", "a3", "a4", "a5", "a6"], typing.Any
]
