# This file was auto-generated by Fern from our API Definition.

import typing

InitializeRenderJobRequestTarget = typing.Union[
    typing.Literal["pdf", "html", "docx", "xlsx", "pptx", "png", "jpg"], typing.Any
]
