# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata


class UpdateTemplateRequestPreviewIds(UniversalBaseModel):
    png_job_id: typing_extensions.Annotated[str, FieldMetadata(alias="pngJobId")] = pydantic.Field()
    """
    ID of the job for the PNG preview
    """

    pdf_job_id: typing_extensions.Annotated[str, FieldMetadata(alias="pdfJobId")] = pydantic.Field()
    """
    ID of the job for the PDF preview
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
