# This file was auto-generated by Fern from our API Definition.

import typing

SaveCreatedTemplateRequestTemplateInfoCategoriesItem = typing.Union[
    typing.Literal["invoice", "mail", "report", "cv", "other"], typing.Any
]
